function [x, err, iter] = block_gauss_seidel( f, x0, tol, iter_max, alpha, beta );
%  Block Gauss-Seidel (underlying method is fixed point method with damping).
%
%  Author: Martin Krosche
%          Institute of Scientific Computing
%          Technische Universitaet Braunschweig
%          Braunschweig, Germany
%
%  Copyright (c) 2009 Martin Krosche. All rights reserved. No warranty. No
%  liability.
%
%  X = BLOCK_GAUSS_SEIDEL( F, X0, ITER ) returns approximation X of
%  two-dimensional equation F(X)=0. X0 is the start vector and ITER the number
%  of iterations. X and X0 are two-dimensional column vectors. ALPHA and BETA
%  are damping parameters.

  if min(size(x0)==[2,1])==0
    error('ONLY 2-DIMENSIONAL NONLINEAR EQUATIONS CAN BE SOLVED!');
  end;

  x    = x0;
  err  = norm([f(x,1);f(x,2)]);
  iter = 0;

  while iter<iter_max && err>tol

    x(1) = x(1) - alpha*f(x,1);
    x(2) = x(2) -  beta*f(x,2);

    err = norm([f(x,1);f(x,2)]);
    iter = iter+1;
  end;
